|
From: <caw...@us...> - 2007-02-28 14:10:19
|
Revision: 2062
http://svn.sourceforge.net/rubyeclipse/?rev=2062&view=rev
Author: cawilliams
Date: 2007-02-28 06:10:11 -0800 (Wed, 28 Feb 2007)
Log Message:
-----------
clean up type safety warnings
Modified Paths:
--------------
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/DefaultProjectLoadpathEntry.java
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/StandardVMRunner.java
trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/IRuntimeLoadpathEntry.java
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/DefaultProjectLoadpathEntry.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/StandardVMRunner.java 2007-02-28 14:02:16 UTC (rev 2061)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/StandardVMRunner.java 2007-02-28 14:10:11 UTC (rev 2062)
@@ -80,7 +80,7 @@
return buf.toString();
}
- protected void addArguments(String[] args, List v) {
+ protected void addArguments(String[] args, List<String> v) {
if (args == null) {
return;
}
@@ -188,7 +188,7 @@
String program= constructProgramString(config);
- List arguments= new ArrayList();
+ List<String> arguments= new ArrayList<String>();
arguments.add(program);
// VM args are the first thing after the ruby program so that users can specify
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/IRuntimeLoadpathEntry.java
===================================================================
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/IRuntimeLoadpathEntry.java 2007-02-28 14:02:16 UTC (rev 2061)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/launching/IRuntimeLoadpathEntry.java 2007-02-28 14:10:11 UTC (rev 2062)
@@ -18,7 +18,7 @@
import org.rubypeople.rdt.core.IRubyProject;
/**
- * Represents an entry on a runtime classpath. A runtime classpath entry
+ * Represents an entry on a runtime loadpath. A runtime loadpath entry
* may refer to one of the following:
* <ul>
* <li>A Ruby project (type <code>PROJECT</code>) - a project entry refers
@@ -28,22 +28,22 @@
* folder in the workspace or in the local file system containing class
* files. An archive may have attached source.</li>
* <li>A variable (type <code>VARIABLE</code>) - a variable refers to a
- * classpath variable, which may refer to a jar.</li>
- * <li>A library (type <code>CONTAINER</code>) - a container refers to classpath
+ * loadpath variable, which may refer to a jar.</li>
+ * <li>A library (type <code>CONTAINER</code>) - a container refers to loadpath
* container variable which refers to a collection of archives derived
* dynamically, on a per project basis.</li>
- * <li>A contributed classpath entry (type <code>OTHER</code>) - a contributed
- * classpath entry is an extension contributed by a plug-in. The resolution
- * of a contributed classpath entry is client defined. See
+ * <li>A contributed loadpath entry (type <code>OTHER</code>) - a contributed
+ * loadpath entry is an extension contributed by a plug-in. The resolution
+ * of a contributed loadpath entry is client defined. See
* <code>IRuntimeLoadpathEntry2</code>.
* </ul>
* <p>
- * Clients may implement this interface for contributed a classpath entry
- * types (i.e. type <code>OTHER</code>). Note, contributed classpath entries
+ * Clients may implement this interface for contributed a loadpath entry
+ * types (i.e. type <code>OTHER</code>). Note, contributed loadpath entries
* are new in 3.0, and are only intended to be contributed by the Ruby debugger.
* </p>
* @since 2.0
- * @see org.eclipse.jdt.launching.IRuntimeLoadpathEntry2
+ * @see org.rubypeople.rdt.launching.IRuntimeLoadpathEntry2
*/
public interface IRuntimeLoadpathEntry {
@@ -87,12 +87,12 @@
/**
* Loadpath property identifier for entries that should appear on the
- * user classpath.
+ * user loadpath.
*/
public static final int USER_CLASSES = 3;
/**
- * Returns this classpath entry's type. The type of a runtime classpath entry is
+ * Returns this loadpath entry's type. The type of a runtime loadpath entry is
* identified by one of the following constants:
* <ul>
* <li><code>PROJECT</code></li>
@@ -104,14 +104,14 @@
* <p>
* Since 3.0, a type of <code>OTHER</code> may be returned.
* </p>
- * @return this classpath entry's type
+ * @return this loadpath entry's type
*/
public int getType();
/**
- * Returns a memento for this classpath entry.
+ * Returns a memento for this loadpath entry.
* <p>
- * Since 3.0, the memento for a contributed classpath entry (i.e. of
+ * Since 3.0, the memento for a contributed loadpath entry (i.e. of
* type <code>OTHER</code>), must be in the form of an XML document,
* with the following element structure:
* <pre>
@@ -123,15 +123,15 @@
* </runtimeLoadpathEntry>
* </pre>
* The <code>id</code> attribute is the unique identifier of the extension
- * that contributed this runtime classpath entry type, via the extension
+ * that contributed this runtime loadpath entry type, via the extension
* point <code>org.eclipse.jdt.launching.runtimeLoadpathEntries</code>.
* The <code>memento</code> element will be used to initialize a
- * restored runtime classpath entry, via the method
+ * restored runtime loadpath entry, via the method
* <code>IRuntimeLoadpathEntry2.initializeFrom(Element memento)</code>. The
* attributes of the <code>memento</code> element are client defined.
* </p>
*
- * @return a memento for this classpath entry
+ * @return a memento for this loadpath entry
* @exception CoreException if an exception occurs generating a memento
*/
public String getMemento() throws CoreException;
@@ -146,9 +146,9 @@
* <li><code>ARCHIVE</code> - the absolute path of the associated archive,
* which may or may not be in the workspace.</li>
* <li><code>VARIABLE</code> - the path corresponding to the associated
- * classpath variable entry.</li>
+ * loadpath variable entry.</li>
* <li><code>CONTAINER</code> - the path corresponding to the associated
- * classpath container variable entry.</li>
+ * loadpath container variable entry.</li>
* <li><code>OTHER</code> - the path returned is client defined.</li>
* </ul>
* <p>
@@ -170,29 +170,29 @@
/**
* Returns a constant indicating where this entry should appear on the
- * runtime classpath by default.
+ * runtime loadpath by default.
* The value returned is one of the following:
* <ul>
* <li><code>STANDARD_CLASSES</code> - a standard entry does not need to appear
- * on the runtime classpath</li>
+ * on the runtime loadpath</li>
* <li><code>BOOTSTRAP_CLASSES</code> - a bootstrap entry should appear on the
* boot path</li>
* <li><code>USER_CLASSES</code> - a user entry should appear on the path
* containing user or application classes</li>
* </ul>
*
- * @return where this entry should appear on the runtime classpath
+ * @return where this entry should appear on the runtime loadpath
*/
public int getLoadpathProperty();
/**
- * Sets whether this entry should appear on the bootstrap classpath,
- * the user classpath, or whether this entry is a standard bootstrap entry
- * that does not need to appear on the classpath.
+ * Sets whether this entry should appear on the bootstrap loadpath,
+ * the user loadpath, or whether this entry is a standard bootstrap entry
+ * that does not need to appear on the loadpath.
* The location is one of:
* <ul>
* <li><code>STANDARD_CLASSES</code> - a standard entry does not need to appear
- * on the runtime classpath</li>
+ * on the runtime loadpath</li>
* <li><code>BOOTSTRAP_CLASSES</code> - a bootstrap entry should appear on the
* boot path</li>
* <li><code>USER_CLASSES</code> - a user entry should appear on the path
@@ -222,21 +222,21 @@
public String getVariableName();
/**
- * Returns a classpath entry equivalent to this runtime classpath entry,
+ * Returns a loadpath entry equivalent to this runtime loadpath entry,
* or <code>null</code> if none.
- * @return a classpath entry equivalent to this runtime classpath entry,
+ * @return a loadpath entry equivalent to this runtime loadpath entry,
* or <code>null</code>
* @since 0.9.0
*/
public ILoadpathEntry getLoadpathEntry();
/**
- * Returns the Ruby project associated with this runtime classpath entry
- * or <code>null</code> if none. Runtime classpath entries of type
+ * Returns the Ruby project associated with this runtime loadpath entry
+ * or <code>null</code> if none. Runtime loadpath entries of type
* <code>CONTAINER</code> may be associated with a project for the
* purposes of resolving the entries in a container.
*
- * @return the Ruby project associated with this runtime classpath entry
+ * @return the Ruby project associated with this runtime loadpath entry
* or <code>null</code> if none
* @since 0.9.0
*/
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/DefaultProjectLoadpathEntry.java 2007-02-28 14:02:16 UTC (rev 2061)
+++ trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/DefaultProjectLoadpathEntry.java 2007-02-28 14:10:11 UTC (rev 2062)
@@ -124,12 +124,12 @@
}
/* (non-Rubydoc)
- * @see org.eclipse.jdt.launching.IRuntimeLoadpathEntry2#getRuntimeLoadpathEntries(org.eclipse.debug.core.ILaunchConfiguration)
+ * @see org.rubypeople.rdt.launching.IRuntimeLoadpathEntry2#getRuntimeLoadpathEntries(org.eclipse.debug.core.ILaunchConfiguration)
*/
public IRuntimeLoadpathEntry[] getRuntimeLoadpathEntries(ILaunchConfiguration configuration) throws CoreException {
ILoadpathEntry entry = RubyCore.newProjectEntry(getRubyProject().getProject().getFullPath());
List classpathEntries = new ArrayList(5);
- List expanding = new ArrayList(5);
+ List<ILoadpathEntry> expanding = new ArrayList<ILoadpathEntry>(5);
expandProject(entry, classpathEntries, expanding);
IRuntimeLoadpathEntry[] runtimeEntries = new IRuntimeLoadpathEntry[classpathEntries.size()];
for (int i = 0; i < runtimeEntries.length; i++) {
@@ -141,8 +141,8 @@
runtimeEntries[i] = (IRuntimeLoadpathEntry)e;
}
}
- // remove bootpath entries - this is a default user classpath
- List ordered = new ArrayList(runtimeEntries.length);
+ // remove bootpath entries - this is a default user loadpath
+ List<IRuntimeLoadpathEntry> ordered = new ArrayList<IRuntimeLoadpathEntry>(runtimeEntries.length);
for (int i = 0; i < runtimeEntries.length; i++) {
if (runtimeEntries[i].getLoadpathProperty() == IRuntimeLoadpathEntry.USER_CLASSES) {
ordered.add(runtimeEntries[i]);
@@ -162,7 +162,7 @@
* expanded (to detect cycles)
* @exception CoreException if unable to expand the classpath
*/
- private void expandProject(ILoadpathEntry projectEntry, List expandedPath, List expanding) throws CoreException {
+ private void expandProject(ILoadpathEntry projectEntry, List expandedPath, List<ILoadpathEntry> expanding) throws CoreException {
expanding.add(projectEntry);
// 1. Get the raw classpath
// 2. Replace source folder entries with a project entry
Modified: trunk/org.rubypeople.rdt.launching/src/org/rubypeople/rdt/internal/launching/StandardVMRunner.java
===================================================================